dj-hitcount
================

.. image:: https://github.com/abhiabhi94/dj-hitcount/actions/workflows/test.yml/badge.svg?branch=main
    :target: https://github.com/abhiabhi94/dj-hitcount/actions
    :alt: Test

.. image:: https://codecov.io/gh/abhiabhi94/dj-hitcount/branch/main/graph/badge.svg?token=JBorE9i0De
  :target: https://codecov.io/gh/abhiabhi94/dj-hitcount
  :alt: Coverage

.. image:: https://badge.fury.io/py/dj-hitcount.svg
    :target: https://pypi.org/project/dj-hitcount/
    :alt: Latest PyPi version

.. image:: https://img.shields.io/pypi/pyversions/dj-hitcount.svg
    :target: https://pypi.python.org/pypi/dj-hitcount/
    :alt: python

.. image:: https://img.shields.io/pypi/djversions/dj-hitcount.svg
    :target: https://pypi.python.org/pypi/dj-hitcount/
    :alt: django

.. image:: https://readthedocs.org/projects/dj-hitcount/badge/?version=latest
    :target: https://dj-hitcount.readthedocs.io/?badge=latest
    :alt: docs

.. image:: https://img.shields.io/github/license/abhiabhi94/dj-hitcount?color=gr
    :target: https://github.com/abhiabhi94/dj-hitcount/blob/main/LICENSE
    :alt: licence


Dj-Hitcount allows you to track the number of hits/views for a particular object.

.. toctree::
   :maxdepth: 2

   overview
   installation
   models
   settings
   management
   example_project
   contribute
   changelog
   migrating-from-django-hitcount

Issues
------

Use the GitHub `issue tracker`_ for dj-hitcount to submit bugs, issues, and feature requests.

.. _issue tracker: https://github.com/abhiabhi94/dj-hitcount/issues
